@@ -36,9 +36,9 @@ many real world case (HTML pages)
 * For each item we are keeping a list of indices.
 We should group items by the length of the indices list (number of occurrences)
 BUT every such group (bucket) should only hold items that their indices form a
-repetitive sequence. So each index of a new item in a bucket should be bigger
-then the last items index but smaller then the next index of the first item.
-In other words, there may be more then one bucket for each number of occurrences
+repetitive sequence. So each index of a new item in a bucket should be larger
+than the last item index but smaller then the next index of the first item.
+In other words, there may be more than one bucket for each number of occurrences
 value.
 
 Important to note: I always keep the original order of the items. In every
@@ -96,9 +96,9 @@ class RepeatPattern(RepeatPatternBase):
 		length = len(first_indices) # all lists are the same length
 		# Make sure all new items are in appropriate places,
 		# last item is special case
-		return all([new_indices[i] > last_indices[i] and \
+		return all(new_indices[i] > last_indices[i] and \
 			(i == length - 1 or new_indices[i] < first_indices[i+1]) \
-			for i in range(length)])
+			for i in range(length))
 
 	@staticmethod
 	def clean(pattern):
@@ -115,8 +115,8 @@ class RepeatPattern(RepeatPatternBase):
 			return False
 		if indices[-1][1] > len(self._input_lst) - EXPANSION_LOOK_AHEAD:
 			return False
-		return all([indices[i][1] < indices[i+1][0] for i in \
-			range(len(indices)-1)])
+		return all(indices[i][1] < indices[i+1][0] for i in \
+			range(len(indices)-1))
 
 	# TODO: Optimize this method (?)
 	def _find_common_item(self, lst_lst):
@@ -192,7 +192,10 @@ class RepeatPattern(RepeatPatternBase):
 	## First level private methods ##
 
 	def _group_items(self):
-		""" Create an indices list for each item in the input list. """
+		""" Create an indices list for each item in the input list.
+		It breaks the indices lists so they will be under the maximum STDV of
+		the system. So each item may have more than one indices list.
+		"""
 		for index, item in enumerate(self._input_lst):
 			self._items_dict[item].append(index)
 		tmp_dict = {}
@@ -282,10 +285,9 @@ class RepeatPattern(RepeatPatternBase):
 
 
 	def process(self, input_lst):
-		""" Find the best pattern in a list of items (see module documentation
+		""" Find the best patterns in a list of items (see module documentation
 		for more details).
-		Returns a list of tow-tuple indices (start, end) of the indices of the
-		best pattern, or None if there is no "best" pattern.
+		Returns the number of patterns found
 		"""
 		self.init(input_lst)
 		self._items_dict = defaultdict(list) # Dictionary of item: indices
@@ -384,5 +386,3 @@ if __name__ == '__main__':
 	RepeatPattern.test(4)
 	print "Test Passed"
 
-
-
